import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
//displaying the title
const render = data => {
  const title = 'Number of houses sold in United States';
  //x-paxix label
  const xValue = d => d.Year;
  const xAxisLabel = 'Years';
  //y-axis label
  const yValue = d => d.United_States;
  const circleRadius = 6;
  const yAxisLabel = 'Num of houses sold';
  //CSS of line chart
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //xScale with year values
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  //yScale with houses sold values
  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  //Creating X-Axis
  const xAxis = axisBottom(xScale)
    .ticks(6)
    .tickSize(-innerHeight)
    .tickPadding(15);

  
  const yAxisTickFormat = number =>
    format('.1s')(number)
      .replace('G', 'B');
  
  //Creating Y-Axis
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
    .tickFormat(yAxisTickFormat);
  
  //Appending y axis to the svg variable
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  //Appending x axis to the svg variable
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  //area graph generator
  const areaGenerator = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d => yScale(yValue(d)))
    .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', areaGenerator(data));
  
  svg.append('text')
      .attr('class', 'title')
      .attr('x', width / 2)
      .attr('y', 45)
      .text(title);
};
// gist of dataset linked
csv('https://gist.githubusercontent.com/sampath5/8838065c51fc7161a7638258775e4c67/raw/ddaafbc2fef994f907faae02f651a26b73cd0469/yearwisesales.csv')
  .then(data => {
    data.forEach(d => {
      d.United_States = +d.United_States;
      d.Year = new Date(d.Year);
    });
    render(data);
  });